Package play
Class ConfProperties
- All Implemented Interfaces:
Serializable,Cloneable,Map<Object,Object>
- Direct Known Subclasses:
OrderSafeProperties
With this helper class one could do the following:
if (!Play.configuration.property("XForwardedSupport", "not-all").hasValue("all") { ... }
instead of:
if (!"ALL".equalsIgnoreCase(Play.configuration.getProperty("XForwardedSupport")) { ... }
- See Also:
-
Nested Class Summary
Nested Classes -
Field Summary
Fields inherited from class java.util.Properties
defaults -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionHelper method of an often recurring type of check on Play's configuration properties.Methods inherited from class java.util.Properties
clear, clone, compute, computeIfAbsent, computeIfPresent, contains, containsKey, containsValue, elements, entrySet, equals, forEach, get, getOrDefault, getProperty, getProperty, hashCode, isEmpty, keys, keySet, list, list, load, load, loadFromXML, merge, propertyNames, put, putAll, putIfAbsent, rehash, remove, remove, replace, replace, replaceAll, save, setProperty, size, store, store, storeToXML, storeToXML, storeToXML, stringPropertyNames, toString, values
-
Constructor Details
-
ConfProperties
public ConfProperties()
-
-
Method Details
-
property
Helper method of an often recurring type of check on Play's configuration properties.
-