Package play

Class Invocation

java.lang.Object
play.Invocation
All Implemented Interfaces:
Runnable
Direct Known Subclasses:
Job

public abstract class Invocation extends Object implements Runnable
An Invocation in something to run in a Play! context
  • Constructor Details

    • Invocation

      public Invocation()
  • Method Details

    • execute

      public abstract void execute()
      Override this method
    • preInit

      protected void preInit()
      Needs this method to do stuff *before* init() is executed. The different Invocation-implementations does a lot of stuff in init() and they might do it before calling super.init()
    • init

      public boolean init() throws IOException
      Init the call (especially useful in DEV mode to detect changes)
      Returns:
      true if successful
      Throws:
      IOException
    • getInvocationContext

      public abstract InvocationContext getInvocationContext()
    • before

      public void before()
      Things to do before an Invocation
    • after

      public void after()
      Things to do after an Invocation. (if the Invocation code has not thrown any exception)
    • onSuccess

      public void onSuccess() throws Exception
      Things to do when the whole invocation has succeeded (before + execute + after)
      Throws:
      Exception
    • onActionInvocationException

      public void onActionInvocationException(Http.Request request, Http.Response response, Throwable e)