Package play

Class Invoker

java.lang.Object
play.Invoker

public class Invoker extends Object
Run some code in a Play! context
  • Field Details

  • Constructor Details

    • Invoker

      public Invoker()
  • Method Details

    • invoke

      public Future<?> invoke(Invocation invocation)
      Run the code in a new thread took from a thread pool.
      Parameters:
      invocation - The code to run
      Returns:
      The future object, to know when the task is completed