Package play

Enum Class Play.Mode

All Implemented Interfaces:
Serializable, Comparable<Play.Mode>, Constable
Enclosing class:
Play

public static enum Play.Mode extends Enum<Play.Mode>
  • Enum Constant Details

    • DEV

      public static final Play.Mode DEV
      Enable development-specific features, e.g. view the documentation at the URL "/@documentation".
    • PROD

      public static final Play.Mode PROD
      Disable development-specific features.
  • Method Details

    • values

      public static Play.Mode[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Play.Mode valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • isDev

      public boolean isDev()
    • isProd

      public boolean isProd()