Class ParamNode

java.lang.Object
play.data.binding.ParamNode
Direct Known Subclasses:
RootParamNode

public class ParamNode extends Object
  • Constructor Details

    • ParamNode

      public ParamNode(String name)
  • Method Details

    • getName

      public String getName()
    • getValues

      public String[] getValues()
    • getFirstValue

      public String getFirstValue(Class<?> type)
    • addChild

      public void addChild(ParamNode child)
    • getChild

      public ParamNode getChild(String name)
    • getChild

      public ParamNode getChild(String name, boolean returnEmptyChildIfNotFound)
    • removeChild

      public boolean removeChild(String name, List<ParamNode.RemovedNode> removedNodesList)
      Removes a child from this node, but stores what is removed to list. Then we can later call which will add it back again. This is a "hack" related to #1195 which makes it possible to reuse the RootParamsNode-structure if you want to perform the bind-operation multiple times.
      Parameters:
      name - the name of the child-node in this paramNode which should be removed.
      removedNodesList - a list where info about what is removed where is stored.
      Returns:
      true if anything was removed.
    • restoreRemovedChildren

      public static void restoreRemovedChildren(List<ParamNode.RemovedNode> removedNodesList)
    • getAllChildren

      public Collection<ParamNode> getAllChildren()
    • getAllChildrenKeys

      public Set<String> getAllChildrenKeys()
    • setValue

      public void setValue(String[] value, String originalKey)
    • getOriginalKey

      public String getOriginalKey()
    • convert

      public static RootParamNode convert(Map<String,String[]> params)