Class ApacheMultipartParser.AutoFileItem

java.lang.Object
play.data.parsing.ApacheMultipartParser.AutoFileItem
All Implemented Interfaces:
org.apache.commons.fileupload.FileItem, org.apache.commons.fileupload.FileItemHeadersSupport
Enclosing class:
ApacheMultipartParser

public static class ApacheMultipartParser.AutoFileItem extends Object implements org.apache.commons.fileupload.FileItem
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
    Default content charset to be used when no explicit charset parameter is provided by the sender.
  • Constructor Summary

    Constructors
    Constructor
    Description
    AutoFileItem(org.apache.commons.fileupload.FileItemStream stream)
     
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    Deletes the underlying storage for a file item, including deleting any associated temporary disk file.
    byte[]
    get()
    Returns the contents of the file as an array of bytes.
    Returns the content charset passed by the agent or null if not defined.
    Returns the content type passed by the agent or null if not defined.
    Returns the name of the field in the multipart form corresponding to this file item.
    org.apache.commons.fileupload.FileItemHeaders
    Returns the file item headers.
    Returns an InputStream that can be used to retrieve the contents of the file.
    Returns the original filename in the client's filesystem.
    Returns an OutputStream that can be used for storing the contents of the file.
    long
    Returns the size of the file.
    Returns the File object for the FileItem's data's temporary location on the disk.
    Returns the contents of the file as a String, using the default character encoding.
    getString(String charset)
    Returns the contents of the file as a String, using the specified encoding.
    protected File
    Creates and returns a File representing a uniquely named temporary file in the configured repository path.
    boolean
    Determines whether or not a FileItem instance represents a simple form field.
    boolean
    Provides a hint as to whether or not the file contents will be read from memory.
    void
    setFieldName(String fieldName)
    Sets the field name used to reference this file item.
    void
    setFormField(boolean state)
    Specifies whether or not a FileItem instance represents a simple form field.
    void
    setHeaders(org.apache.commons.fileupload.FileItemHeaders pHeaders)
    Sets the file item headers.
     
    void
    write(File file)
    A convenience method to write an uploaded item to disk.

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
  • Field Details

    • DEFAULT_CHARSET

      public static final String DEFAULT_CHARSET
      Default content charset to be used when no explicit charset parameter is provided by the sender. Media subtypes of the "text" type are defined to have a default charset value of "ISO-8859-1" when received via HTTP.
      See Also:
  • Constructor Details

    • AutoFileItem

      public AutoFileItem(org.apache.commons.fileupload.FileItemStream stream)
  • Method Details

    • getInputStream

      public InputStream getInputStream() throws IOException
      Returns an InputStream that can be used to retrieve the contents of the file.
      Specified by:
      getInputStream in interface org.apache.commons.fileupload.FileItem
      Returns:
      An InputStream that can be used to retrieve the contents of the file.
      Throws:
      IOException - if an error occurs.
    • getContentType

      public String getContentType()
      Returns the content type passed by the agent or null if not defined.
      Specified by:
      getContentType in interface org.apache.commons.fileupload.FileItem
      Returns:
      The content type passed by the agent or null if not defined.
    • getCharSet

      public String getCharSet()
      Returns the content charset passed by the agent or null if not defined.
      Returns:
      The content charset passed by the agent or null if not defined.
    • getName

      public String getName()
      Returns the original filename in the client's filesystem.
      Specified by:
      getName in interface org.apache.commons.fileupload.FileItem
      Returns:
      The original filename in the client's filesystem.
    • isInMemory

      public boolean isInMemory()
      Provides a hint as to whether or not the file contents will be read from memory.
      Specified by:
      isInMemory in interface org.apache.commons.fileupload.FileItem
      Returns:
      true if the file contents will be read from memory; false otherwise.
    • getSize

      public long getSize()
      Returns the size of the file.
      Specified by:
      getSize in interface org.apache.commons.fileupload.FileItem
      Returns:
      The size of the file, in bytes.
    • get

      public byte[] get()
      Returns the contents of the file as an array of bytes. If the contents of the file were not yet cached in memory, they will be loaded from the disk storage and cached.
      Specified by:
      get in interface org.apache.commons.fileupload.FileItem
      Returns:
      The contents of the file as an array of bytes.
    • getString

      public String getString(String charset) throws UnsupportedEncodingException
      Returns the contents of the file as a String, using the specified encoding. This method uses get() to retrieve the contents of the file.
      Specified by:
      getString in interface org.apache.commons.fileupload.FileItem
      Parameters:
      charset - The charset to use.
      Returns:
      The contents of the file, as a string.
      Throws:
      UnsupportedEncodingException - if the requested character encoding is not available.
    • getString

      public String getString()
      Returns the contents of the file as a String, using the default character encoding. This method uses get() to retrieve the contents of the file.
      Specified by:
      getString in interface org.apache.commons.fileupload.FileItem
      Returns:
      The contents of the file, as a string.
    • write

      public void write(File file) throws IOException, org.apache.commons.fileupload.FileUploadException
      A convenience method to write an uploaded item to disk. The client code is not concerned with whether or not the item is stored in memory, or on disk in a temporary location. They just want to write the uploaded item to a file.

      This implementation first attempts to rename the uploaded item to the specified destination file, if the item was originally written to disk. Otherwise, the data will be copied to the specified file.

      This method is only guaranteed to work once, the first time it is invoked for a particular item. This is because, in the event that the method renames a temporary file, that file will no longer be available to copy or rename again at a later time.

      Specified by:
      write in interface org.apache.commons.fileupload.FileItem
      Parameters:
      file - The File into which the uploaded item should be stored.
      Throws:
      IOException
      org.apache.commons.fileupload.FileUploadException
    • delete

      public void delete()
      Deletes the underlying storage for a file item, including deleting any associated temporary disk file. Although this storage will be deleted automatically when the FileItem instance is garbage collected, this method can be used to ensure that this is done at an earlier time, thus preserving system resources.
      Specified by:
      delete in interface org.apache.commons.fileupload.FileItem
    • getFieldName

      public String getFieldName()
      Returns the name of the field in the multipart form corresponding to this file item.
      Specified by:
      getFieldName in interface org.apache.commons.fileupload.FileItem
      Returns:
      The name of the form field.
      See Also:
    • setFieldName

      public void setFieldName(String fieldName)
      Sets the field name used to reference this file item.
      Specified by:
      setFieldName in interface org.apache.commons.fileupload.FileItem
      Parameters:
      fieldName - The name of the form field.
      See Also:
    • isFormField

      public boolean isFormField()
      Determines whether or not a FileItem instance represents a simple form field.
      Specified by:
      isFormField in interface org.apache.commons.fileupload.FileItem
      Returns:
      true if the instance represents a simple form field; false if it represents an uploaded file.
      See Also:
    • setFormField

      public void setFormField(boolean state)
      Specifies whether or not a FileItem instance represents a simple form field.
      Specified by:
      setFormField in interface org.apache.commons.fileupload.FileItem
      Parameters:
      state - true if the instance represents a simple form field; false if it represents an uploaded file.
      See Also:
    • getOutputStream

      public OutputStream getOutputStream()
      Returns an OutputStream that can be used for storing the contents of the file.
      Specified by:
      getOutputStream in interface org.apache.commons.fileupload.FileItem
      Returns:
      An OutputStream that can be used for storing the contents of the file.
    • getStoreLocation

      public File getStoreLocation()
      Returns the File object for the FileItem's data's temporary location on the disk. Note that for FileItems that have their data stored in memory, this method will return null. When handling large files, you can use File.renameTo(File) to move the file to new location without copying the data, if the source and destination locations reside within the same logical volume.
      Returns:
      The data file, or null if the data is stored in memory.
    • getTempFile

      protected File getTempFile()
      Creates and returns a File representing a uniquely named temporary file in the configured repository path. The lifetime of the file is tied to the lifetime of the FileItem instance; the file will be deleted when the instance is garbage collected.
      Returns:
      The File to be used for temporary storage.
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • getHeaders

      public org.apache.commons.fileupload.FileItemHeaders getHeaders()
      Returns the file item headers.
      Specified by:
      getHeaders in interface org.apache.commons.fileupload.FileItemHeadersSupport
      Returns:
      The file items headers.
    • setHeaders

      public void setHeaders(org.apache.commons.fileupload.FileItemHeaders pHeaders)
      Sets the file item headers.
      Specified by:
      setHeaders in interface org.apache.commons.fileupload.FileItemHeadersSupport
      Parameters:
      pHeaders - The file items headers.