Package play.data.validation
package play.data.validation
-
ClassDescriptionThis field must be a valid email.A validation errorThis date must be in the future.This date must be in the past.This field must be a valid IP address.This field must be a valid IP address.This field must be true.This field must match the regexp.This field must be lower than.This field size must be lower than.This field must be greater than.This field size must be equal or greater than.This field is a password.This field contain a phone number This validation is relaxed and is intended to enforce a basic phone pattern.This field must be lower than and greater than.This field is required.Check that a field or or field in a context is unique.Check which proof if one or a set of properties is unique.This field must be a valid url.This bean must satisfy all checks.