Package play.db

Class Configuration

java.lang.Object
play.db.Configuration

public class Configuration extends Object
  • Constructor Details

    • Configuration

      public Configuration(String configurationName)
  • Method Details

    • isDefault

      public boolean isDefault()
    • getDbNames

      public static Set<String> getDbNames()
    • getProperty

      public String getProperty(String key)
    • getProperty

      public String getProperty(String key, String defaultString)
    • put

      public Object put(String key, String value)
      Add a parameter in the configuration
      Parameters:
      key - the key of the parameter
      value - the value of the parameter
      Returns:
      the previous value of the key in this hashtable, or null if it did not have one
    • getProperties

      public Map<String,String> getProperties()