Package play.db
Record Class DB.ExtendedDatasource
java.lang.Object
java.lang.Record
play.db.DB.ExtendedDatasource
- Enclosing class:
- DB
@NullMarked
@CheckReturnValue
public static record DB.ExtendedDatasource(DataSource dataSource, String destroyMethod)
extends Record
-
Constructor Summary
ConstructorsConstructorDescriptionExtendedDatasource(DataSource dataSource, String destroyMethod) Creates an instance of aExtendedDatasourcerecord class. -
Method Summary
Modifier and TypeMethodDescriptionReturns the value of thedataSourcerecord component.Returns the value of thedestroyMethodrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
ExtendedDatasource
Creates an instance of aExtendedDatasourcerecord class.- Parameters:
dataSource- the value for thedataSourcerecord componentdestroyMethod- the value for thedestroyMethodrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
dataSource
Returns the value of thedataSourcerecord component.- Returns:
- the value of the
dataSourcerecord component
-
destroyMethod
Returns the value of thedestroyMethodrecord component.- Returns:
- the value of the
destroyMethodrecord component
-