Package play.db
Class DBPlugin
java.lang.Object
play.PlayPlugin
play.db.DBPlugin
- All Implemented Interfaces:
Comparable<PlayPlugin>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classNeeded because DriverManager will not load a driver ouside of the system classloader -
Field Summary
FieldsFields inherited from class play.PlayPlugin
index -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected DataSourceFactoryfactory(Configuration dbConfig) voidonActionInvocationFinally(Http.Request request, Http.Response response) Called at the end of the action invocation (either in case of success or any failure).voidCalled at application start (and at each reloading) Time to start stateful things.voidCalled at application stop (and before each reloading) Time to shut down stateful things.voidprotected StringMethods inherited from class play.PlayPlugin
afterActionInvocation, afterApplicationStart, afterInvocation, beforeActionInvocation, beforeInvocation, bind, compareTo, detectChange, disable, getJsonStatus, getMessage, getStatus, isEnabled, loadTemplate, onActionInvocationException, onActionInvocationResult, onActionInvocationResult, onConfigurationRead, onInvocationSuccess, onJobInvocationException, onLoad, rawInvocation, routeRequest
-
Field Details
-
url
-
-
Constructor Details
-
DBPlugin
public DBPlugin()
-
-
Method Details
-
factory
-
onApplicationStart
public void onApplicationStart()Description copied from class:PlayPluginCalled at application start (and at each reloading) Time to start stateful things.- Overrides:
onApplicationStartin classPlayPlugin
-
testDataSource
- Throws:
SQLException
-
onApplicationStop
public void onApplicationStop()Description copied from class:PlayPluginCalled at application stop (and before each reloading) Time to shut down stateful things.- Overrides:
onApplicationStopin classPlayPlugin
-
onActionInvocationFinally
public void onActionInvocationFinally(@Nonnull Http.Request request, @Nonnull Http.Response response) Description copied from class:PlayPluginCalled at the end of the action invocation (either in case of success or any failure). Time to close request-specific things.- Overrides:
onActionInvocationFinallyin classPlayPlugin
-
onJobInvocationFinally
public void onJobInvocationFinally()- Overrides:
onJobInvocationFinallyin classPlayPlugin
-