Package play.modules.logger
Class RequestLogPlugin
java.lang.Object
play.PlayPlugin
play.modules.logger.RequestLogPlugin
- All Implemented Interfaces:
Comparable<PlayPlugin>
-
Field Summary
Fields inherited from class play.PlayPlugin
index -
Method Summary
Modifier and TypeMethodDescriptionvoidbeforeActionInvocation(Http.Request request, Http.Response response, @Nullable Scope.Session session, Scope.RenderArgs renderArgs, Scope.Flash flash, Method actionMethod) Called before an 'action' invocation, ie an HTTP request processing.voidonActionInvocationException(Http.Request request, Http.Response response, Throwable e) voidonActionInvocationFinally(Http.Request request, Http.Response response) Called at the end of the action invocation (either in case of success or any failure).voidonActionInvocationResult(Http.Request request, Http.Response response, Scope.Session session, Scope.Flash flash, Scope.RenderArgs renderArgs, Result result) Called when the action method has thrown a result.voidrouteRequest(Http.Request request) Let some plugins route themselvesMethods inherited from class play.PlayPlugin
afterActionInvocation, afterApplicationStart, afterInvocation, beforeInvocation, bind, compareTo, detectChange, disable, getJsonStatus, getMessage, getStatus, isEnabled, loadTemplate, onActionInvocationResult, onApplicationStart, onApplicationStop, onConfigurationRead, onInvocationSuccess, onJobInvocationException, onJobInvocationFinally, onLoad, rawInvocation
-
Method Details
-
routeRequest
Description copied from class:PlayPluginLet some plugins route themselves- Overrides:
routeRequestin classPlayPlugin- Parameters:
request- the current request
-
beforeActionInvocation
public void beforeActionInvocation(Http.Request request, Http.Response response, @Nullable Scope.Session session, Scope.RenderArgs renderArgs, Scope.Flash flash, Method actionMethod) Description copied from class:PlayPluginCalled before an 'action' invocation, ie an HTTP request processing.- Overrides:
beforeActionInvocationin classPlayPlugin
-
onActionInvocationResult
public void onActionInvocationResult(Http.Request request, Http.Response response, Scope.Session session, Scope.Flash flash, Scope.RenderArgs renderArgs, Result result) Description copied from class:PlayPluginCalled when the action method has thrown a result.- Overrides:
onActionInvocationResultin classPlayPluginresult- The result object for the request.
-
onActionInvocationException
- Overrides:
onActionInvocationExceptionin classPlayPlugin
-
onActionInvocationFinally
Description copied from class:PlayPluginCalled at the end of the action invocation (either in case of success or any failure). Time to close request-specific things.- Overrides:
onActionInvocationFinallyin classPlayPlugin
-