Package play.mvc
Class Controller
java.lang.Object
play.mvc.Controller
- All Implemented Interfaces:
PlayContextController,PlayController
- Direct Known Subclasses:
RebelController
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected ActionContextprotected Scope.Flashprotected Scope.Paramsprotected Scope.RenderArgsprotected Http.Requestprotected Http.Responseprotected Scope.Sessionprotected Validation -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected BadRequestprotected voidprotected static voidDeprecated.instead if throwing an exception we recommend to RETURN the result.protected static voidDeprecated.instead if throwing an exception we recommend to RETURN the result.protected ForbiddenvoidsetContext(ActionContext actionContext) protected Viewprotected ViewviewResult(String templateName)
-
Field Details
-
actionContext
-
request
-
response
-
session
-
flash
-
params
-
renderArgs
-
validation
-
-
Constructor Details
-
Controller
public Controller()
-
-
Method Details
-
setContext
- Specified by:
setContextin interfacePlayContextController
-
checkAuthenticity
protected void checkAuthenticity() -
forbidden
Deprecated.instead if throwing an exception we recommend to RETURN the result. It makes your code clear and testable. Use methodforbiddenResult().This "Play1-style" method throwsForbiddenexception. -
forbidden
Deprecated.instead if throwing an exception we recommend to RETURN the result. It makes your code clear and testable. Use methodforbiddenResult().This "Play1-style" method throwsForbiddenexception. -
badRequest
-
viewResult
-
viewResult
-
forbiddenResult
-