Package play.mvc
Interface PlayController
- All Known Subinterfaces:
PlayContextController
- All Known Implementing Classes:
Controller,RebelController
public interface PlayController
Marker interface for play controllers
This is the class that your controllers should implement when they need very few capabilities.
In most cases, you can extend Controller which provides a basic set of features
for controllers.