Package play.mvc

Record Class Router.MatchingRoute

java.lang.Object
java.lang.Record
play.mvc.Router.MatchingRoute
Enclosing class:
Router

public static record Router.MatchingRoute(Router.Route route, Map<String,String> args) extends Record
  • Constructor Details

    • MatchingRoute

      public MatchingRoute(Router.Route route, Map<String,String> args)
      Creates an instance of a MatchingRoute record class.
      Parameters:
      route - the value for the route record component
      args - the value for the args record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • route

      public Router.Route route()
      Returns the value of the route record component.
      Returns:
      the value of the route record component
    • args

      public Map<String,String> args()
      Returns the value of the args record component.
      Returns:
      the value of the args record component