Package play
package play
-
ClassDescriptionWith this helper class one could do the following:An Invocation in something to run in a Play! contextThe class/method that will be invoked by the current operationRun some code in a Play! contextMain framework classA framework plugin