Package play.plugins

Class PluginCollection

java.lang.Object
play.plugins.PluginCollection

@NullMarked public class PluginCollection extends Object
Class handling all plugins used by Play.

Loading/reloading/enabling/disabling is handled here.

This class also exposes many PlayPlugin-methods which when called, the method is executed on all enabled plugins.

Since all the enabled-plugins-iteration is done here, the code elsewhere is cleaner.