Package play.utils
Class FastRuntimeException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
play.utils.FastRuntimeException
- All Implemented Interfaces:
Serializable
- Direct Known Subclasses:
Result
Fast Exception - skips creating stackTrace.
More info here.
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionFastRuntimeException(String desc) FastRuntimeException(String desc, Throwable cause) FastRuntimeException(Throwable cause) -
Method Summary
Modifier and TypeMethodDescriptionSince we override this method, no stacktrace is generated - much fasterMethods inherited from class java.lang.Throwable
addSuppressed, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
FastRuntimeException
public FastRuntimeException() -
FastRuntimeException
-
FastRuntimeException
-
FastRuntimeException
-
-
Method Details
-
fillInStackTrace
Since we override this method, no stacktrace is generated - much faster- Overrides:
fillInStackTracein classThrowable- Returns:
- always null
-