Package play.utils
Class HTML.HtmlCharacterEntityReferences
java.lang.Object
play.utils.HTML.HtmlCharacterEntityReferences
- Enclosing class:
- HTML
-
Constructor Summary
ConstructorsConstructorDescriptionReturns a new set of character entity references reflecting the HTML 4.0 character set. -
Method Summary
Modifier and TypeMethodDescriptioncharconvertToCharacter(String entityReference) Return the char mapped to the given entityReference or -1.convertToReference(char character) Return the reference mapped to the given character ornull.intReturn the number of supported entity references.booleanisMappedToReference(char character) Return true if the given character is mapped to a supported entity reference.
-
Constructor Details
-
HtmlCharacterEntityReferences
public HtmlCharacterEntityReferences()Returns a new set of character entity references reflecting the HTML 4.0 character set.
-
-
Method Details
-
getSupportedReferenceCount
public int getSupportedReferenceCount()Return the number of supported entity references.- Returns:
- Number of supported entity references
-
isMappedToReference
public boolean isMappedToReference(char character) Return true if the given character is mapped to a supported entity reference.- Parameters:
character- The given character- Returns:
- true if the given character is mapped to a supported entity reference
-
convertToReference
Return the reference mapped to the given character ornull.- Parameters:
character- The given character- Returns:
- The reference mapped to the given character or
null
-
convertToCharacter
Return the char mapped to the given entityReference or -1.- Parameters:
entityReference- The given entityReference- Returns:
- The char mapped to the given entityReference or -1.
-