Package play.utils
Class HTTP
java.lang.Object
play.utils.HTTP
-
Nested Class Summary
Nested Classes -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic StringfixCaseForHttpHeader(String headerName) Use this method to make sure you have the correct casing of a http header name.static HTTP.ContentTypeWithEncodingparseContentType(String contentType)
-
Constructor Details
-
HTTP
public HTTP()
-
-
Method Details
-
parseContentType
-
fixCaseForHttpHeader
Use this method to make sure you have the correct casing of a http header name. eg: fixes 'content-type' to 'Content-Type'- Parameters:
headerName- The given header name to check- Returns:
- The correct header name
-