Package play.utils
package play.utils
-
ClassDescriptionAction<T>Fast Exception - skips creating stackTrace.Java utilsCustom impl of java.util.properties that preserves the key-order from the file and that reads the properties-file in utf-8OS detectionsLike Java's Properties, but with: encoding generic type helper.SSL Sockets created by this factory won't check if certificates are signed with a root certificate (or chained from root)