Package play
Class Invoker
java.lang.Object
play.Invoker
Run some code in a Play! context
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic ScheduledThreadPoolExecutorMain executor for requests invocations. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionFuture<?>invoke(Invocation invocation) Run the code in a new thread took from a thread pool.
-
Field Details
-
executor
Main executor for requests invocations.
-
-
Constructor Details
-
Invoker
public Invoker()
-
-
Method Details
-
invoke
Run the code in a new thread took from a thread pool.- Parameters:
invocation- The code to run- Returns:
- The future object, to know when the task is completed
-