Package play
Enum Class Play.Mode
- All Implemented Interfaces:
Serializable,Comparable<Play.Mode>,Constable
- Enclosing class:
- Play
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
-
Enum Constant Details
-
DEV
Enable development-specific features, e.g. view the documentation at the URL "/@documentation". -
PROD
Disable development-specific features.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
isDev
public boolean isDev() -
isProd
public boolean isProd()
-