Package play.data.binding
Class ParamNode
java.lang.Object
play.data.binding.ParamNode
- Direct Known Subclasses:
RootParamNode
-
Nested Class Summary
Nested Classes -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidstatic RootParamNodegetFirstValue(Class<?> type) getName()String[]booleanremoveChild(String name, List<ParamNode.RemovedNode> removedNodesList) Removes a child from this node, but stores what is removed to list.static voidrestoreRemovedChildren(List<ParamNode.RemovedNode> removedNodesList) void
-
Constructor Details
-
ParamNode
-
-
Method Details
-
getName
-
getValues
-
getFirstValue
-
addChild
-
getChild
-
getChild
-
removeChild
Removes a child from this node, but stores what is removed to list. Then we can later call which will add it back again. This is a "hack" related to #1195 which makes it possible to reuse the RootParamsNode-structure if you want to perform the bind-operation multiple times.- Parameters:
name- the name of the child-node in this paramNode which should be removed.removedNodesList- a list where info about what is removed where is stored.- Returns:
- true if anything was removed.
-
restoreRemovedChildren
-
getAllChildren
-
getAllChildrenKeys
-
setValue
-
getOriginalKey
-
convert
-