Package play.db
Class Configuration
java.lang.Object
play.db.Configuration
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetProperty(String key) getProperty(String key, String defaultString) booleanAdd a parameter in the configuration
-
Constructor Details
-
Configuration
-
-
Method Details
-
isDefault
public boolean isDefault() -
getDbNames
-
getProperty
-
getProperty
-
put
Add a parameter in the configuration- Parameters:
key- the key of the parametervalue- the value of the parameter- Returns:
- the previous value of the key in this hashtable, or null if it did not have one
-
getProperties
-