Package play.libs
Class WS
java.lang.Object
play.PlayPlugin
play.libs.WS
- All Implemented Interfaces:
Comparable<PlayPlugin>
Simple HTTP client to make webservices requests.
Get latest BBC World news as a RSS content
HttpResponse response = WS.url("http://newsrss.bbc.co.uk/rss/newsonline_world_edition/front_page/rss.xml").get();
Document xmldoc = response.getXml();
// the real pain begins here...
Search what Yahoo! thinks of Google (starting from the 30th result).
HttpResponse response = WS.url("http://search.yahoo.com/search?p=%s&pstart=1&b=%s", "Google killed me", "30").get();
if (response.getStatus() == 200) {
html = response.getString();
}
-
Field Summary
Fields inherited from class play.PlayPlugin
index -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidCalled at application start (and at each reloading) Time to start stateful things.voidCalled at application stop (and before each reloading) Time to shut down stateful things.static WSRequestDeprecated.Using this static method make it hard to test.Methods inherited from class play.PlayPlugin
afterActionInvocation, afterApplicationStart, afterInvocation, beforeActionInvocation, beforeInvocation, bind, compareTo, detectChange, disable, getJsonStatus, getMessage, getStatus, isEnabled, loadTemplate, onActionInvocationException, onActionInvocationFinally, onActionInvocationResult, onActionInvocationResult, onConfigurationRead, onInvocationSuccess, onJobInvocationException, onJobInvocationFinally, onLoad, rawInvocation, routeRequest
-
Constructor Details
-
WS
public WS()
-
-
Method Details
-
onApplicationStop
public void onApplicationStop()Description copied from class:PlayPluginCalled at application stop (and before each reloading) Time to shut down stateful things.- Overrides:
onApplicationStopin classPlayPlugin
-
onApplicationStart
public void onApplicationStart()Description copied from class:PlayPluginCalled at application start (and at each reloading) Time to start stateful things.- Overrides:
onApplicationStartin classPlayPlugin
-
url
Deprecated.Using this static method make it hard to test. A better option is to @Inject WSClient instance to your class.Build a WebService Request with the given URL. This object support chaining style programming for adding params, file, headers to requests.- Parameters:
url- of the request- Returns:
- a WSRequest on which you can add params, file headers using a chaining style programming.
-